/* eslint-disable prettier/prettier */
// monitoring.gateway.ts
import { WebSocketGateway, WebSocketServer, SubscribeMessage, MessageBody } from '@nestjs/websockets';
import { Subscription } from 'rxjs';
import { Server } from 'socket.io';
import { AppService } from 'src/app.service';
@WebSocketGateway({
    cors: {
        origins: '*',
        optionsSuccessStatus: 200,
    }
})
export class SocketGateway {
    @WebSocketServer()
    server: Server;

    constructor(private appService: AppService) {
        const subscription: Subscription = this.appService.getMessage().subscribe({
            next: data => {
                console.log(data)
                this.server.emit('message', data)
            },
            error: err => {
                subscription.unsubscribe()
                console.error(err)
            },
            complete: () => {
                subscription.unsubscribe()
            }
        })
    }

    // Samples from official nest git
    @SubscribeMessage(`message`)
    messageHandler(@MessageBody() data: any) {
        console.log(data)
    }

    // this two methods are non essential. as they are used to keep track of the local ui port 3000, not keeping track of the actual clients 
    handleConnection(client: any) {
        console.log('UI connected:', client.id);
    }

    handleDisconnect(client: any) {
        console.log('UI disconnected:', client.id);
    }

}
